const fs = require('fs')
const path = require('path')
const assert = require('assert')
const postcss = require('postcss')
const cssstats = require('cssstats')

const src = fs.readFileSync(path.resolve(__dirname, '../src/index.css'), 'utf8')

let css
let stats

describe('css', function() {
  it('should compile', function(cb) {
    assert.doesNotThrow(function() {
      postcss()
        .process(src)
        .then(function (result) {
          css = result.css
          cb()
        })
    })
  })

  it('should compile to string', function() {
    assert.equal(typeof css, 'string')
  })

  it('should be css', function() {
    assert.doesNotThrow(function() {
      stats = cssstats(css, { safe: false })
    })
  })

  it('should have rules', function() {
    assert(stats.rules.total > 0)
  })

  it('should have declarations', function() {
    assert(stats.declarations.total > 0)
  })

  it('should have properties', function() {
    assert(Object.keys(stats.declarations.properties).length > 0)
  })
})
